After applying smbinning.scaling to the model, smbinning.scoring generates a data frame
with the final Score and additional fields with the points assigned to each characteristic so the user
can see how the final score is calculated. Example shown on smbinning.scaling section.
smbinning.scoring.gen(smbscaled, dataset)Object generated using smbinning.scaling.
A data frame.
The command smbinning.scoring generates a data frame with the final scaled Score and its
corresponding scaled weights per characteristic.